/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { InnerTransaction, Transaction, PublicAccount } from 'symbol-sdk';
import { AbstractCommand } from './AbstractCommand';
/**
 * @class NIP13.LockBalance
 * @package NIP13 Token Commands
 * @since v0.5.0
 * @description Class that describes a token command for locking (part of) balances of NIP13 compliant tokens.
 * @summary
 * This token command accepts the following arguments:
 *
 * | Argument | Description | Example |
 * | --- | --- | --- |
 * | partition | Token holder partition account (gets locked) | `new PublicAccount(...)` |
 * | locker | Token locker account (lock account) | `new PublicAccount(...)` |
 * | amount | Number of shares to be locked | `1` |
 */
export declare class LockBalance extends AbstractCommand {
    /**
     * @description List of **required** arguments for this token command.
     */
    arguments: string[];
    /**
     * @description Getter for the command name.
     * @see {BaseCommand.name}
     **/
    get name(): string;
    /**
     * Getter for the command descriptor.
     *
     * @return {string}
     **/
    get descriptor(): string;
    /**
     * @description Builds the inner transactions necessary for the
     *              execution of a `LockBalance` command.
     * @see {AbstractCommand.transactions}
     * @return {Transaction[]} Aggregate bonded transaction
     **/
    protected get transactions(): Transaction[];
    /**
     * Helper method for creating partitions on Symbol networks.
     *
     * @param {PublicAccount} partition
     * @param {PublicAccount} locker
     */
    protected createBalanceLock(partition: PublicAccount, locker: PublicAccount): {
        transactions: InnerTransaction[];
        signers: PublicAccount[];
    };
}
