"use strict";
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
// commands
const CreateToken_1 = require("./commands/CreateToken");
const CreatePartition_1 = require("./commands/CreatePartition");
const TransferOwnership_1 = require("./commands/TransferOwnership");
const TransferOwnershipWithData_1 = require("./commands/TransferOwnershipWithData");
const BatchTransferOwnership_1 = require("./commands/BatchTransferOwnership");
const BatchTransferOwnershipWithData_1 = require("./commands/BatchTransferOwnershipWithData");
const ForcedTransfer_1 = require("./commands/ForcedTransfer");
const LockBalance_1 = require("./commands/LockBalance");
const UnlockBalance_1 = require("./commands/UnlockBalance");
const ModifyMetadata_1 = require("./commands/ModifyMetadata");
const ModifyRestriction_1 = require("./commands/ModifyRestriction");
const DelegateIssuerPower_1 = require("./commands/DelegateIssuerPower");
const RevokeIssuerPower_1 = require("./commands/RevokeIssuerPower");
const AttachDocument_1 = require("./commands/AttachDocument");
var NIP13;
(function (NIP13) {
    /**
     * @class NIP13.CreateToken
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for creating NIP13 compliant tokens.
     */
    class CreateToken extends CreateToken_1.CreateToken {
    }
    NIP13.CreateToken = CreateToken;
    /**
     * @class NIP13.CreatePartition
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for creating NIP13 token holder partitions.
     */
    class CreatePartition extends CreatePartition_1.CreatePartition {
    }
    NIP13.CreatePartition = CreatePartition;
    /**
     * @class NIP13.TransferOwnership
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for transferring the ownership of NIP13 compliant tokens.
     */
    class TransferOwnership extends TransferOwnership_1.TransferOwnership {
    }
    NIP13.TransferOwnership = TransferOwnership;
    /**
     * @class NIP13.TransferOwnershipWithData
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for transferring the ownership of NIP13 compliant tokens and attaching data.
     */
    class TransferOwnershipWithData extends TransferOwnershipWithData_1.TransferOwnershipWithData {
    }
    NIP13.TransferOwnershipWithData = TransferOwnershipWithData;
    /**
     * @class NIP13.BatchTransferOwnership
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for batch transferring the ownership of NIP13 compliant tokens.
     */
    class BatchTransferOwnership extends BatchTransferOwnership_1.BatchTransferOwnership {
    }
    NIP13.BatchTransferOwnership = BatchTransferOwnership;
    /**
     * @class NIP13.BatchTransferOwnershipWithData
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for batch transferring the ownership of NIP13 compliant tokens and attaching data.
     */
    class BatchTransferOwnershipWithData extends BatchTransferOwnershipWithData_1.BatchTransferOwnershipWithData {
    }
    NIP13.BatchTransferOwnershipWithData = BatchTransferOwnershipWithData;
    /**
     * @class NIP13.ForcedTransfer
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for force-transferring the ownership of NIP13 compliant tokens.
     */
    class ForcedTransfer extends ForcedTransfer_1.ForcedTransfer {
    }
    NIP13.ForcedTransfer = ForcedTransfer;
    /**
     * @class NIP13.LockBalance
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for locking a (part of) NIP13 token holder partition balance.
     */
    class LockBalance extends LockBalance_1.LockBalance {
    }
    NIP13.LockBalance = LockBalance;
    /**
     * @class NIP13.UnlockBalance
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for unlocking a (part of) NIP13 token holder partition balance.
     */
    class UnlockBalance extends UnlockBalance_1.UnlockBalance {
    }
    NIP13.UnlockBalance = UnlockBalance;
    /**
     * @class NIP13.ModifyMetadata
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for modifying metadata of NIP13 compliant tokens.
     */
    class ModifyMetadata extends ModifyMetadata_1.ModifyMetadata {
    }
    NIP13.ModifyMetadata = ModifyMetadata;
    /**
     * @class NIP13.ModifyRestriction
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for modifying restrictions of NIP13 compliant tokens.
     */
    class ModifyRestriction extends ModifyRestriction_1.ModifyRestriction {
    }
    NIP13.ModifyRestriction = ModifyRestriction;
    /**
     * @class NIP13.DelegateIssuerPower
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for adding operators to NIP13 compliant tokens.
     */
    class DelegateIssuerPower extends DelegateIssuerPower_1.DelegateIssuerPower {
    }
    NIP13.DelegateIssuerPower = DelegateIssuerPower;
    /**
     * @class NIP13.RevokeIssuerPower
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for removing operators from NIP13 compliant tokens.
     */
    class RevokeIssuerPower extends RevokeIssuerPower_1.RevokeIssuerPower {
    }
    NIP13.RevokeIssuerPower = RevokeIssuerPower;
    /**
     * @class NIP13.AttachDocument
     * @package interfaces
     * @since v0.1.0
     * @description Class that describes a token command for attaching documents to NIP13 compliant tokens or token holder partitions.
     */
    class AttachDocument extends AttachDocument_1.AttachDocument {
    }
    NIP13.AttachDocument = AttachDocument;
})(NIP13 = exports.NIP13 || (exports.NIP13 = {}));
