"use strict";
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @class SecuritiesMetadata
 * @package models
 * @since v0.1.0
 * @description Model that describes the metadata of internal securities.
 * @link https://en.wikipedia.org/wiki/International_Securities_Identification_Number
 * @link https://en.wikipedia.org/wiki/ISO_10962
 * @link https://en.wikipedia.org/wiki/Market_Identifier_Code
 */
class SecuritiesMetadata {
    /**
     * Constructor for SecuritiesMetadata objects
     *
     * @param {string} source
     */
    constructor(
    /**
     * @description The market identifier code
     * @link https://en.wikipedia.org/wiki/Market_Identifier_Code
     */
    mic, 
    /**
     * @description The international securities identification number
     * @link https://en.wikipedia.org/wiki/International_Securities_Identification_Number
     */
    isin, 
    /**
     * @description The classification of the financial instrument
     * @link https://en.wikipedia.org/wiki/ISO_10962
     */
    classification, 
    /**
     * @description The website of the financial instrument
     */
    website, 
    /**
     * @description The sector of the financial instrument (e.g.: Capital Goods)
     */
    sector, 
    /**
     * @description The industry of the financial instrument (e.g.: Computer Manufacturing)
     */
    industry, 
    /**
     * @description Custom metadata entries
     */
    customMetadata = {}) {
        this.mic = mic;
        this.isin = isin;
        this.classification = classification;
        this.website = website;
        this.sector = sector;
        this.industry = industry;
        this.customMetadata = customMetadata;
    }
}
exports.SecuritiesMetadata = SecuritiesMetadata;
