/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Address, Metadata, MetadataType } from 'symbol-sdk';
import { Service, TokenIdentifier } from '../../../../index';
import { SecuritiesMetadata } from '../models/SecuritiesMetadata';
declare type FormattedMetadata = {
    scopedMetadataKey: string;
    senderAddress: Address;
    targetAddress: Address;
    metadataType: MetadataType;
    targetId: string | undefined;
    metadataValue: string;
};
/**
 * @class MetadataService
 * @package services
 * @since v0.1.0
 * @description Class that describes a service around token metadata features.
 */
export declare class MetadataService extends Service {
    /**
     * @description Known NIP13 metadata keys
     */
    static KNOWN_METADATAS: {
        [k: string]: string;
    };
    /**
     * Helper function to retrieve known mosaic metadata keys
     *
     * @param {string}  hexKey
     * @return {string}
     */
    static getKnownMetadataKey: (hexKey: string) => string;
    /**
     * Helper function to format metadata entries
     *
     * @param {Metadata} metadataEntry
     * @return {any}
     */
    protected formatMetadata(metadata: Metadata): FormattedMetadata;
    /**
     * Read token partitions from token operators
     * network information.
     *
     * @param {TokenIdentifier}       tokenId     The token identifier.
     * @return {SecuritiesMetadata}
     */
    getMetadataFromNetwork(tokenId: TokenIdentifier): Promise<SecuritiesMetadata>;
}
export {};
