"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const symbol_sdk_1 = require("symbol-sdk");
// internal dependencies
const index_1 = require("../../../../index");
const TransactionService_1 = require("./TransactionService");
/**
 * @class MosaicService
 * @package services
 * @since v0.1.0
 * @description Class that describes a service around token metadata features.
 */
class MosaicService extends index_1.Service {
    /**
     * Read published security tokens. Security tokens MUST publish
     * a creation proof transaction on the authority account.
     *
     * @param {PublicAccount}       authority
     * @return {SecuritiesMetadata}
     */
    getMosaicsFromNetwork(authority, descriptor = '') {
        return __awaiter(this, void 0, void 0, function* () {
            // initialize APIs
            const service = new TransactionService_1.TransactionService(this.context.network.factoryHttp.createAccountRepository(), this.context.network.factoryHttp.createChainRepository(), this.context.network.factoryHttp.createTransactionRepository(), this.context.network.factoryHttp.createReceiptRepository(), 100);
            // Step 1) read transfers to find partition accounts
            const transactions = yield service.getIncomingTransfers(authority.address, undefined, 0).toPromise();
            // filter partition transfer transactions
            const markedTransfers = transactions.filter(tx => tx.message.payload.startsWith(descriptor));
            // read recipients to find partition accounts
            const mosaicIds = markedTransfers.map(t => t.message).map(message => {
                // identifier:mosaicId:name
                const mosaicId = message.payload.substr(descriptor.length).split(':')[1];
                return new symbol_sdk_1.MosaicId(mosaicId);
            });
            return mosaicIds;
        });
    }
}
exports.MosaicService = MosaicService;
