"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// internal dependencies
const index_1 = require("../../../../index");
/**
 * @class MultisigService
 * @package services
 * @since v0.1.0
 * @description Class that describes a service around multi-signature features.
 */
class MultisigService extends index_1.Service {
    /**
     * Reduce a multisig graph to an array of multisig
     * account information.
     *
     * @param {MultisigAccountGraphInfo} graph
     * @return {MultisigAccountInfo[]}
     */
    getMultisigAccountInfoFromGraph(graph) {
        // get addresses
        const infos = [...graph.multisigAccounts.keys()]
            .sort((a, b) => b - a) // sort from top to bottom
            .map((key) => graph.multisigAccounts.get(key) || [])
            .filter((x) => x.length > 0);
        // flatten output
        return infos.reduce((prev, it) => [...it]);
    }
}
exports.MultisigService = MultisigService;
