"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
// internal dependencies
const index_1 = require("../../../../index");
const SecuritiesRestrictions_1 = require("../models/SecuritiesRestrictions");
/**
 * @class RestrictionService
 * @package services
 * @since v0.5.1
 * @description Class that describes a service around token restrictions features.
 */
class RestrictionService extends index_1.Service {
    /**
     * Read token restrictions from network
     *
     * @param {TokenIdentifier}       tokenId     The token identifier.
     * @return {SecuritiesRestrictions}
     */
    getRestrictionsFromNetwork(tokenId) {
        return __awaiter(this, void 0, void 0, function* () {
            // read restriction entries for token from network
            const config = yield this.context.network.factoryHttp.createRestrictionMosaicRepository()
                .getMosaicGlobalRestriction(tokenId.toMosaicId())
                .toPromise();
            const restrictions = {};
            config.restrictions.forEach((value, key) => {
                const entry = {
                    [value.restrictionType]: parseInt(value.restrictionValue)
                };
                restrictions[key] = entry;
            });
            // XXX map known restriction keys
            return new SecuritiesRestrictions_1.SecuritiesRestrictions(restrictions);
        });
    }
}
exports.RestrictionService = RestrictionService;
