"use strict";
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const mocha_1 = require("mocha");
const symbol_sdk_1 = require("symbol-sdk");
// internal dependencies
const index_1 = require("../mocks/index");
const index_2 = require("../../index");
const NetworkConfig_1 = require("../../src/models/NetworkConfig");
// prepare
const mnemonic = index_1.getTestMnemonic();
const token = new index_2.NIP13.Token(new NetworkConfig_1.NetworkConfig('http://api-01.us-west-1.symboldev.network:3000', symbol_sdk_1.NetworkType.TEST_NET, 'ACECD90E7B248E012803228ADB4424F0D966D24149B72E58987D2BF2F2AF03C4', new symbol_sdk_1.MosaicId('519FC24B9223E0B4')), mnemonic);
const defaultNIP13 = 'TDEE6S3YUMS6A37XSW3JB7VPT7QTMYCYKDUACQU4'; // m/44'/4343'/1313'/0'/0'
mocha_1.describe('NIP13 Standard --->', () => {
    mocha_1.it('Revision should be 1', () => {
        // assert
        chai_1.expect(index_2.NIP13.Revision).to.be.equal(1);
    });
    mocha_1.it('export Token class', () => {
        chai_1.expect(index_2.NIP13.Token).not.to.be.undefined;
    });
    mocha_1.it('export TokenMetadata class', () => {
        chai_1.expect(index_2.NIP13.TokenMetadata).not.to.be.undefined;
    });
    mocha_1.describe('constructor() should', () => {
        mocha_1.it('derive default NIP13 derivation path', () => {
            // assert
            chai_1.expect(token.target.address.plain()).to.be.equal(defaultNIP13);
        });
    });
});
